==> savane-1.0.3.1.tar.gz: savane/frontend/php/include/trackers_run/admin/index.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: index.php,v 1.20 2004/03/13 18:22:06 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
#
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

$is_admin_page='y';

if ($group_id && user_ismember($group_id,'A')) 
{


  # FIXME: test about user are completely broken 
  # (if admin, if logged in later!)

  # Initialize global bug structures
  trackers_init($group_id);

  /*
	Show main page
  */

  trackers_header_admin(array());

  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2') || user_ismember($group_id,'A')) 
    {
      echo '<h3><a href="field_usage.php?group='.$group_name.'">'._("Manage Field Usage").'</a></h3>';
      echo '<dd>'._("Define what fields you want to use with this tracker for this project.").' ('._("remark: some of the fields are mandatory and cannot be removed").').</dd>';
      echo '<h3><a href="field_values.php?group='.$group_name.'">'._("Manage Field Values").'</a></h3>';
      echo '<dd>'._("Define the set of values for the fields you have decided to use in this tracker for this specific project.").' </dd>';
    }

  if (user_isloggedin()) 
    {
      echo '<h3><a href="editqueryforms.php?group='.$group_name.'">'._("Manage Query Forms").'</a></h3>';
      echo '<dd>'._("Define project-wide query form: what search criteria to use and what item fields to show in the query form table.").'</dd>';

      echo '<h3><a href="notification_settings.php?group='.$group_name.'">'._("Email Notification Settings").'</a></h3>';
      echo '<dd>'._("You can define email notification rules for this tracker.").'</dd>';
    }

  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2') || user_ismember($group_id,'A')) 
    {
      echo '<h3><a href="other_settings.php?group='.$group_name.'">'._("Other Configuration Settings").'</a></h3>';
      echo '<dd>'._("Define introductory messages for submission forms&hellip;").'</dd>';
    }

  trackers_footer(array());

} 
else
{
  
  #browse for group first message

  if (!$group_id) 
    {
      exit_no_group();
    } 
  else 
    {
      exit_permission_denied();
    }
}

?>

==> savane-1.0.4.tar.gz: savane/frontend/php/include/trackers_run/admin/index.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: index.php,v 1.21 2004/09/22 08:11:51 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

$is_admin_page='y';

if ($group_id && user_ismember($group_id,'A')) 
{


  # FIXME: test about user are completely broken 
  # (if admin, if logged in later!)

  # Initialize global bug structures
  trackers_init($group_id);

  /*
	Show main page
  */

  trackers_header_admin(array());

  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2') || user_ismember($group_id,'A')) 
    {
      echo '<h3><a href="field_usage.php?group='.$group_name.'">'._("Manage Field Usage").'</a></h3>';
      echo '<dd>'._("Define what fields you want to use with this tracker for this project.").' ('._("remark: some of the fields are mandatory and cannot be removed").').</dd>';
      echo '<h3><a href="field_values.php?group='.$group_name.'">'._("Manage Field Values").'</a></h3>';
      echo '<dd>'._("Define the set of values for the fields you have decided to use in this tracker for this specific project.").' </dd>';
    }

  if (user_isloggedin()) 
    {
      echo '<h3><a href="editqueryforms.php?group='.$group_name.'">'._("Manage Query Forms").'</a></h3>';
      echo '<dd>'._("Define project-wide query form: what search criteria to use and what item fields to show in the query form table.").'</dd>';

      echo '<h3><a href="userperms.php?group='.$group_name.'">'._("Set Permissions").'</a></h3>';
      echo '<dd>'._("You can restrict posting on this trackers depending on user authentication level. For instance, you can forbid to anonymous posts.").'</dd>';

      echo '<h3><a href="notification_settings.php?group='.$group_name.'">'._("Notification Settings").'</a></h3>';
      echo '<dd>'._("You can define email notification rules for this tracker.").'</dd>';
    }

  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2') || user_ismember($group_id,'A')) 
    {
      echo '<h3><a href="other_settings.php?group='.$group_name.'">'._("Other Configuration Settings").'</a></h3>';
      echo '<dd>'._("Define introductory messages for submission forms&hellip;").'</dd>';
    }

  trackers_footer(array());

} 
else
{
  
  #browse for group first message

  if (!$group_id) 
    {
      exit_no_group();
    } 
  else 
    {
      exit_permission_denied();
    }
}

?>
